@@ -36,28 +36,6 @@ sub new {
 	return $self
 }
 
-sub KeyArrowNavig {
-	my ($self, $dcol, $drow) = @_;
-	return undef if $self->anchorInitialize;
-	my $pool = $self->pool;
-	my $i = $self->anchorGet;
-	if ($drow eq 0) { #horizontal move
-		my $col = $i->column;
-		my $row = $i->row;
-		if ($dcol > 0) { #to the right
-			$row ++
-		} else { #to the left
-			$row --;
-		}
-		my $index = $self->indexColumnRow(0, $row);
-		return $self->getIndex($index);
-	} else { #vertical move
-		my $index = $self->index($i->name);
-		$index = $index + $drow;
-		return $self->getIndex($index);
-	}
-}
-
 sub nextPosition {
 	my ($self, $x, $y, $column, $row) = @_;
 	my $cellheight = $self->cellHeight;
